FuzzyLocale enum
Supported locales for fuzzy time string localization. Using ISO 639-1 (2 letter codes) language codes.
Values
- en → const FuzzyLocale
-
English
const FuzzyLocale('en') - es → const FuzzyLocale
-
Spanish
const FuzzyLocale('es') - fr → const FuzzyLocale
-
French
const FuzzyLocale('fr') - pt → const FuzzyLocale
-
Portuguese
const FuzzyLocale('pt') - de → const FuzzyLocale
-
German
const FuzzyLocale('de') - it → const FuzzyLocale
-
Italian
const FuzzyLocale('it')
Properties
- code → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
FuzzyLocale> - A constant List of the values in this enum, in order of their declaration.